/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpWaypointApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application#id DataHcpWaypointApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Input variables for the Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application#input_variables DataHcpWaypointApplication#input_variables}
    */
    readonly inputVariables?: DataHcpWaypointApplicationInputVariables[] | cdktf.IResolvable;
    /**
    * The name of the Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application#name DataHcpWaypointApplication#name}
    */
    readonly name?: string;
    /**
    * The ID of the HCP project where the Waypoint Application is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application#project_id DataHcpWaypointApplication#project_id}
    */
    readonly projectId?: string;
}
export interface DataHcpWaypointApplicationInputVariables {
}
export declare function dataHcpWaypointApplicationInputVariablesToTerraform(struct?: DataHcpWaypointApplicationInputVariables | cdktf.IResolvable): any;
export declare function dataHcpWaypointApplicationInputVariablesToHclTerraform(struct?: DataHcpWaypointApplicationInputVariables | cdktf.IResolvable): any;
export declare class DataHcpWaypointApplicationInputVariablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataHcpWaypointApplicationInputVariables | cdktf.IResolvable | undefined;
    set internalValue(value: DataHcpWaypointApplicationInputVariables | cdktf.IResolvable | undefined);
    get name(): string;
    get value(): string;
    get variableType(): string;
}
export declare class DataHcpWaypointApplicationInputVariablesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataHcpWaypointApplicationInputVariables[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataHcpWaypointApplicationInputVariablesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application hcp_waypoint_application}
*/
export declare class DataHcpWaypointApplication extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_waypoint_application";
    /**
    * Generates CDKTF code for importing a DataHcpWaypointApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataHcpWaypointApplication to import
    * @param importFromId The id of the existing DataHcpWaypointApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataHcpWaypointApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/data-sources/waypoint_application hcp_waypoint_application} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpWaypointApplicationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataHcpWaypointApplicationConfig);
    get applicationTemplateId(): string;
    get applicationTemplateName(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inputVariables;
    get inputVariables(): DataHcpWaypointApplicationInputVariablesList;
    putInputVariables(value: DataHcpWaypointApplicationInputVariables[] | cdktf.IResolvable): void;
    resetInputVariables(): void;
    get inputVariablesInput(): cdktf.IResolvable | DataHcpWaypointApplicationInputVariables[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get namespaceId(): string;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    get readmeMarkdown(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
