/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WaypointAddOnDefinitionConfig extends cdktf.TerraformMetaArguments {
    /**
    * A longer description of the Add-on Definition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#description WaypointAddOnDefinition#description}
    */
    readonly description: string;
    /**
    * List of labels attached to this Add-on Definition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#labels WaypointAddOnDefinition#labels}
    */
    readonly labels?: string[];
    /**
    * The name of the Add-on Definition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#name WaypointAddOnDefinition#name}
    */
    readonly name: string;
    /**
    * The ID of the HCP project where the Waypoint Add-on Definition is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#project_id WaypointAddOnDefinition#project_id}
    */
    readonly projectId?: string;
    /**
    * The markdown template for the Add-on Definition README.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#readme_markdown_template WaypointAddOnDefinition#readme_markdown_template}
    */
    readonly readmeMarkdownTemplate?: string;
    /**
    * A short summary of the Add-on Definition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#summary WaypointAddOnDefinition#summary}
    */
    readonly summary: string;
    /**
    * Terraform Cloud Workspace details
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#terraform_cloud_workspace_details WaypointAddOnDefinition#terraform_cloud_workspace_details}
    */
    readonly terraformCloudWorkspaceDetails: WaypointAddOnDefinitionTerraformCloudWorkspaceDetails;
    /**
    * Terraform Cloud no-code Module details.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#terraform_no_code_module WaypointAddOnDefinition#terraform_no_code_module}
    */
    readonly terraformNoCodeModule: WaypointAddOnDefinitionTerraformNoCodeModule;
    /**
    * List of variable options for the template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#variable_options WaypointAddOnDefinition#variable_options}
    */
    readonly variableOptions?: WaypointAddOnDefinitionVariableOptions[] | cdktf.IResolvable;
}
export interface WaypointAddOnDefinitionTerraformCloudWorkspaceDetails {
    /**
    * Name of the Terraform Cloud Workspace
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#name WaypointAddOnDefinition#name}
    */
    readonly name: string;
    /**
    * Tetraform Cloud Project ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#terraform_project_id WaypointAddOnDefinition#terraform_project_id}
    */
    readonly terraformProjectId: string;
}
export declare function waypointAddOnDefinitionTerraformCloudWorkspaceDetailsToTerraform(struct?: WaypointAddOnDefinitionTerraformCloudWorkspaceDetails | cdktf.IResolvable): any;
export declare function waypointAddOnDefinitionTerraformCloudWorkspaceDetailsToHclTerraform(struct?: WaypointAddOnDefinitionTerraformCloudWorkspaceDetails | cdktf.IResolvable): any;
export declare class WaypointAddOnDefinitionTerraformCloudWorkspaceDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaypointAddOnDefinitionTerraformCloudWorkspaceDetails | cdktf.IResolvable | undefined;
    set internalValue(value: WaypointAddOnDefinitionTerraformCloudWorkspaceDetails | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _terraformProjectId?;
    get terraformProjectId(): string;
    set terraformProjectId(value: string);
    get terraformProjectIdInput(): string | undefined;
}
export interface WaypointAddOnDefinitionTerraformNoCodeModule {
    /**
    * Terraform Cloud no-code Module Source
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#source WaypointAddOnDefinition#source}
    */
    readonly source: string;
    /**
    * Terraform Cloud no-code Module Version
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#version WaypointAddOnDefinition#version}
    */
    readonly version: string;
}
export declare function waypointAddOnDefinitionTerraformNoCodeModuleToTerraform(struct?: WaypointAddOnDefinitionTerraformNoCodeModule | cdktf.IResolvable): any;
export declare function waypointAddOnDefinitionTerraformNoCodeModuleToHclTerraform(struct?: WaypointAddOnDefinitionTerraformNoCodeModule | cdktf.IResolvable): any;
export declare class WaypointAddOnDefinitionTerraformNoCodeModuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaypointAddOnDefinitionTerraformNoCodeModule | cdktf.IResolvable | undefined;
    set internalValue(value: WaypointAddOnDefinitionTerraformNoCodeModule | cdktf.IResolvable | undefined);
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
}
export interface WaypointAddOnDefinitionVariableOptions {
    /**
    * Variable name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#name WaypointAddOnDefinition#name}
    */
    readonly name: string;
    /**
    * List of options
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#options WaypointAddOnDefinition#options}
    */
    readonly options: string[];
    /**
    * Whether the variable is editable by the user creating an add-on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#user_editable WaypointAddOnDefinition#user_editable}
    */
    readonly userEditable?: boolean | cdktf.IResolvable;
    /**
    * Variable type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#variable_type WaypointAddOnDefinition#variable_type}
    */
    readonly variableType: string;
}
export declare function waypointAddOnDefinitionVariableOptionsToTerraform(struct?: WaypointAddOnDefinitionVariableOptions | cdktf.IResolvable): any;
export declare function waypointAddOnDefinitionVariableOptionsToHclTerraform(struct?: WaypointAddOnDefinitionVariableOptions | cdktf.IResolvable): any;
export declare class WaypointAddOnDefinitionVariableOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WaypointAddOnDefinitionVariableOptions | cdktf.IResolvable | undefined;
    set internalValue(value: WaypointAddOnDefinitionVariableOptions | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _options?;
    get options(): string[];
    set options(value: string[]);
    get optionsInput(): string[] | undefined;
    private _userEditable?;
    get userEditable(): boolean | cdktf.IResolvable;
    set userEditable(value: boolean | cdktf.IResolvable);
    resetUserEditable(): void;
    get userEditableInput(): boolean | cdktf.IResolvable | undefined;
    private _variableType?;
    get variableType(): string;
    set variableType(value: string);
    get variableTypeInput(): string | undefined;
}
export declare class WaypointAddOnDefinitionVariableOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WaypointAddOnDefinitionVariableOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WaypointAddOnDefinitionVariableOptionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition hcp_waypoint_add_on_definition}
*/
export declare class WaypointAddOnDefinition extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_waypoint_add_on_definition";
    /**
    * Generates CDKTF code for importing a WaypointAddOnDefinition resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WaypointAddOnDefinition to import
    * @param importFromId The id of the existing WaypointAddOnDefinition that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WaypointAddOnDefinition to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on_definition hcp_waypoint_add_on_definition} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WaypointAddOnDefinitionConfig
    */
    constructor(scope: Construct, id: string, config: WaypointAddOnDefinitionConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): string[];
    set labels(value: string[]);
    resetLabels(): void;
    get labelsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _readmeMarkdownTemplate?;
    get readmeMarkdownTemplate(): string;
    set readmeMarkdownTemplate(value: string);
    resetReadmeMarkdownTemplate(): void;
    get readmeMarkdownTemplateInput(): string | undefined;
    private _summary?;
    get summary(): string;
    set summary(value: string);
    get summaryInput(): string | undefined;
    private _terraformCloudWorkspaceDetails;
    get terraformCloudWorkspaceDetails(): WaypointAddOnDefinitionTerraformCloudWorkspaceDetailsOutputReference;
    putTerraformCloudWorkspaceDetails(value: WaypointAddOnDefinitionTerraformCloudWorkspaceDetails): void;
    get terraformCloudWorkspaceDetailsInput(): cdktf.IResolvable | WaypointAddOnDefinitionTerraformCloudWorkspaceDetails | undefined;
    private _terraformNoCodeModule;
    get terraformNoCodeModule(): WaypointAddOnDefinitionTerraformNoCodeModuleOutputReference;
    putTerraformNoCodeModule(value: WaypointAddOnDefinitionTerraformNoCodeModule): void;
    get terraformNoCodeModuleInput(): cdktf.IResolvable | WaypointAddOnDefinitionTerraformNoCodeModule | undefined;
    private _variableOptions;
    get variableOptions(): WaypointAddOnDefinitionVariableOptionsList;
    putVariableOptions(value: WaypointAddOnDefinitionVariableOptions[] | cdktf.IResolvable): void;
    resetVariableOptions(): void;
    get variableOptionsInput(): cdktf.IResolvable | WaypointAddOnDefinitionVariableOptions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
