/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WaypointAddOnConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Application that this Add-on is created for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on#application_id WaypointAddOn#application_id}
    */
    readonly applicationId: string;
    /**
    * The ID of the Add-on Definition that this Add-on is created from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on#definition_id WaypointAddOn#definition_id}
    */
    readonly definitionId: string;
    /**
    * The name of the Add-on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on#name WaypointAddOn#name}
    */
    readonly name: string;
    /**
    * The ID of the HCP project where the Waypoint AddOn is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on#project_id WaypointAddOn#project_id}
    */
    readonly projectId?: string;
}
export interface WaypointAddOnOutputValues {
}
export declare function waypointAddOnOutputValuesToTerraform(struct?: WaypointAddOnOutputValues): any;
export declare function waypointAddOnOutputValuesToHclTerraform(struct?: WaypointAddOnOutputValues): any;
export declare class WaypointAddOnOutputValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WaypointAddOnOutputValues | undefined;
    set internalValue(value: WaypointAddOnOutputValues | undefined);
    get name(): string;
    get sensitive(): cdktf.IResolvable;
    get type(): string;
    get value(): string;
}
export declare class WaypointAddOnOutputValuesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WaypointAddOnOutputValuesOutputReference;
}
export interface WaypointAddOnTerraformNoCodeModule {
}
export declare function waypointAddOnTerraformNoCodeModuleToTerraform(struct?: WaypointAddOnTerraformNoCodeModule): any;
export declare function waypointAddOnTerraformNoCodeModuleToHclTerraform(struct?: WaypointAddOnTerraformNoCodeModule): any;
export declare class WaypointAddOnTerraformNoCodeModuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaypointAddOnTerraformNoCodeModule | undefined;
    set internalValue(value: WaypointAddOnTerraformNoCodeModule | undefined);
    get source(): string;
    get version(): string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on hcp_waypoint_add_on}
*/
export declare class WaypointAddOn extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_waypoint_add_on";
    /**
    * Generates CDKTF code for importing a WaypointAddOn resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WaypointAddOn to import
    * @param importFromId The id of the existing WaypointAddOn that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WaypointAddOn to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.91.0/docs/resources/waypoint_add_on hcp_waypoint_add_on} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WaypointAddOnConfig
    */
    constructor(scope: Construct, id: string, config: WaypointAddOnConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    get createdBy(): string;
    private _definitionId?;
    get definitionId(): string;
    set definitionId(value: string);
    get definitionIdInput(): string | undefined;
    get description(): string;
    get id(): string;
    get installCount(): number;
    get labels(): string[];
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _outputValues;
    get outputValues(): WaypointAddOnOutputValuesList;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    get readmeMarkdown(): string;
    get status(): number;
    get summary(): string;
    private _terraformNoCodeModule;
    get terraformNoCodeModule(): WaypointAddOnTerraformNoCodeModuleOutputReference;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
